@@ -65,6 +65,22 @@ public interface HostService extends MeasurableService {
      * @status added
      */
     interface Approve {
+        /**
+         * Host to approve.
+         *
+         * @author Aleksei Slaikovskii <aslaikov@redhat.com>
+         * @date 24 Apr 2017
+         * @status added
+         */
+        @In Host host();
+
+        /**
+         * Cluster where the host will be added after approving it.
+         *
+         * @author Aleksei Slaikovskii <aslaikov@redhat.com>
+         * @date 24 Apr 2017
+         * @status added
+         */
         @In Cluster cluster();
 
         /**
@@ -216,17 +232,54 @@ public interface HostService extends MeasurableService {
     /**
      * Get the host details.
      *
+     * [source]
+     * ----
+     * GET /ovirt-engine/api/hosts/123
+     * ----
+     *
      * @author Oved Ourfali <oourfali@redhat.com>
-     * @date 14 Sep 2016
+     * @author Aleksei Slaikovskii <aslaikov@redhat.com>
+     * @date 24 Apr 2017
      * @status added
      */
     interface Get {
+        /**
+         * Queried host.
+         *
+         * @author Aleksei Slaikovskii <aslaikov@redhat.com>
+         * @date 24 Apr 2017
+         * @status added
+         */
         @Out Host host();
 
         /**
          * Indicates if the results should be filtered according to the permissions of the user.
          */
         @In Boolean filter();
+
+        /**
+         * Indicates if all of the attributes of the host should be included in the response.
+         *
+         * By default the following attributes are excluded:
+         *
+         * - `hosted_engine`
+         *
+         * For example, to retrieve the complete representation of host '123':
+         *
+         * ....
+         * GET /ovirt-engine/api/hosts/123?all_content=true
+         * ....
+         *
+         * NOTE: These attributes are not included by default because retrieving them impacts performance. They are
+         * seldom used and require additional queries to the database. Use this parameter with caution and only when
+         * specifically required.
+         *
+         * @author Juan Hernandez <juan.hernandez@redhat.com>
+         * @author Tahlia Richardson <trichard@redhat.com>
+         * @date 26 Apr 2017
+         * @status updated_by_docs
+         */
+        @In Boolean allContent();
     }
 
     /**
