@@ -18,6 +18,7 @@ package org.ovirt.engine.sdk4.internal.services;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.net.URISyntaxException;
+import java.util.Map;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpDelete;
 import org.apache.http.client.methods.HttpGet;
@@ -27,6 +28,7 @@ import org.apache.http.entity.ByteArrayEntity;
 import org.apache.http.util.EntityUtils;
 import org.ovirt.api.metamodel.runtime.xml.XmlReader;
 import org.ovirt.api.metamodel.runtime.xml.XmlWriter;
+import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.builders.OpenStackImageProviderBuilder;
@@ -44,17 +46,28 @@ public class OpenstackImageProviderServiceImpl extends ServiceImpl implements Op
         super(connection, path);
     }
     
-    private class GetRequestImpl implements GetRequest {
+    private class GetRequestImpl extends BaseRequest<GetRequest, GetResponse> implements GetRequest {
         public GetResponse send() {
             HttpGet request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpGet(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -96,7 +109,7 @@ public class OpenstackImageProviderServiceImpl extends ServiceImpl implements Op
         return new GetRequestImpl();
     }
     
-    private class RemoveRequestImpl implements RemoveRequest {
+    private class RemoveRequestImpl extends BaseRequest<RemoveRequest, RemoveResponse> implements RemoveRequest {
         private Boolean async;
         public RemoveRequest async(Boolean async) {
             this.async = async;
@@ -110,12 +123,23 @@ public class OpenstackImageProviderServiceImpl extends ServiceImpl implements Op
                 if (async != null) {
                     uriBuilder.addParameter("async", XmlWriter.renderBoolean(async));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpDelete(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
@@ -138,7 +162,7 @@ public class OpenstackImageProviderServiceImpl extends ServiceImpl implements Op
         return new RemoveRequestImpl();
     }
     
-    private class UpdateRequestImpl implements UpdateRequest {
+    private class UpdateRequestImpl extends BaseRequest<UpdateRequest, UpdateResponse> implements UpdateRequest {
         private Boolean async;
         public UpdateRequest async(Boolean async) {
             this.async = async;
@@ -163,6 +187,11 @@ public class OpenstackImageProviderServiceImpl extends ServiceImpl implements Op
                 if (async != null) {
                     uriBuilder.addParameter("async", XmlWriter.renderBoolean(async));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpPut(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
@@ -180,6 +209,12 @@ public class OpenstackImageProviderServiceImpl extends ServiceImpl implements Op
                 throw new Error("Failed to parse response", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
